/* $Workfile: OtxJtag.h $   $Revision: 1 $    $Modtime: 9/24/09 2:45p $  */
#ifndef OTX_JTAG_H
#define OTX_JTAG_H
/*******************************************************************************

  @doc PublicHwApi OtxJtag

  Copyright (C) 2001 - 2007 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxJtag | Prototypes for the JTAG Functions

  @contents2
  OtxJtag.h |

  @index func | OtxJtag

  @contents2
  OTX JTAG - OtxJtagXXX() | The API functions for the JTAG TBC device

  @head3 OtxJtagXXX() Function Reference |

  @index func | OtxJtag

*******************************************************************************/

#ifdef __cplusplus
  extern "C" {
#endif

#include "OtxType.h"
#include "OtxDef.h"

#include "OtxJtagD.h"


/*******************************************************************************

  @func
    Control function for the JTAG TBC device. 

  @xref
    <t OtxJtagControlCmdE> 

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxJtagControl(
  IN  OTX_HANDLE          hDevice,      // @parm Handle to the TBC Device
  IN  OtxJtagControlCmdE  nCmd          // @parm Command to be executed
);


/*******************************************************************************

  @func
    Scan in the Instruction Register

  @xref
    <f OtxJtagScanDr>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxJtagScanIr(
  IN  OTX_HANDLE          hDevice,      // @parm Handle to the TBC Device
  IN  OTX_INT32           nTms,         // @parm TMS chain number (0-7)
  IN  char                *pszUCommand, // @parm Instruction string of be scanned in
  OUT  char               *pszUOutBuf   // @parm Instruction string scanned out
);


/*******************************************************************************

  @func
    Scan in the Data Register

  @xref
    <f OtxJtagScanIr>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxJtagScanDr(
  IN  OTX_HANDLE          hDevice,      // @parm Handle to the TBC Device
  IN  OTX_INT32           nTms,         // @parm TMS chain number (0-7)
  IN  char                *pszUDataIn,  // @parm Data string to be scanned in
  OUT  char               *psUzDataOut  // @parm Data string scanned out
);


/*******************************************************************************

  @func
    Shift in Data (no state transitions)

  @xref
    <f OtxJtagScanIr>

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxJtagShiftDr(
  IN  OTX_HANDLE          hDevice,      // @parm Handle to the TBC Device
  IN  OTX_INT32           nTms,         // @parm TMS chain number (0-7)
  IN  char                *pszUDataIn,  // @parm Data string to be shifted in
  OUT  char               *psUzDataOut  // @parm Data string shifted out
);



#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2001 - 2007

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OTX_JTAG_H
